/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 04469
 |         NATIONAL SURVEY OF SUBSTANCE ABUSE TREATMENT SERVICES
 |                            (N-SSATS), 2005
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\04469-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE mode      1='(1) Phone' 2='(2) Mail' 9='(9) Web' ;
  VALUE stfips    1='(01) ALABAMA' 2='(02) ALASKA' 4='(04) ARIZONA'
                  5='(05) ARKANSAS' 6='(06) CALIFORNIA' 8='(08) COLORADO'
                  9='(09) CONNECTICUT' 10='(10) DELAWARE'
                  11='(11) DIST OF COLUMBIA' 12='(12) FLORIDA'
                  13='(13) GEORGIA' 15='(15) HAWAII' 16='(16) IDAHO'
                  17='(17) ILLINOIS' 18='(18) INDIANA' 19='(19) IOWA'
                  20='(20) KANSAS' 21='(21) KENTUCKY' 22='(22) LOUISIANA'
                  23='(23) MAINE' 24='(24) MARYLAND' 25='(25) MASSACHUSETTS'
                  26='(26) MICHIGAN' 27='(27) MINNESOTA'
                  28='(28) MISSISSIPPI' 29='(29) MISSOURI' 30='(30) MONTANA'
                  31='(31) NEBRASKA' 32='(32) NEVADA' 33='(33) NEW HAMPSHIRE'
                  34='(34) NEW JERSEY' 35='(35) NEW MEXICO'
                  36='(36) NEW YORK' 37='(37) NORTH CAROLINA'
                  38='(38) NORTH DAKOTA' 39='(39) OHIO' 40='(40) OKLAHOMA'
                  41='(41) OREGON' 42='(42) PENNSYLVANIA'
                  44='(44) RHODE ISLAND' 45='(45) SOUTH CAROLINA'
                  46='(46) SOUTH DAKOTA' 47='(47) TENNESSEE' 48='(48) TEXAS'
                  49='(49) UTAH' 50='(50) VERMONT' 51='(51) VIRGINIA'
                  53='(53) WASHINGTON' 54='(54) WEST VIRGINIA'
                  55='(55) WISCONSIN' 56='(56) WYOMING'
                  60='(60) AMERICAN SAMOA' 64='(64) FED MICRONESIA'
                  66='(66) GUAM' 70='(70) PALAU' 72='(72) PUERTO RICO'
                  78='(78) VIRGIN ISLANDS' ;
  VALUE region    0='(0) US Jurisdiction/Territory' 1='(1) Northeast'
                  2='(2) Midwest' 3='(3) South' 4='(4) West' ;
  VALUE division  0='(0) US Jurisdiction/Territory' 1='(1) New England'
                  2='(2) Mid-Atlantic' 3='(3) East North Central'
                  4='(4) West North Central' 5='(5) South Atlantic'
                  6='(6) East South Central' 7='(7) West South Central'
                  8='(8) Mountain' 9='(9) Pacific' ;
  VALUE othnontx  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE detox     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE treatmt   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE admin     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE focus     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Substance abuse treatment services'
                  2='(2) Mental health services'
                  3='(3) Mix of mental health and substance abuse'
                  4='(4) General health care' 5='(5) Other' ;
  VALUE ownershp  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Private for-profit organization'
                  2='(2) Private non-profit organization'
                  3='(3) State government'
                  4='(4) Local, county, or community government'
                  5='(5) Tribal government' 6='(6) Federal government' ;
  VALUE fedown    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Department of Veterans Affairs'
                  2='(2) Department of Defense' 3='(3) Indian Health Service'
                  4='(4) Other' ;
  VALUE loc15fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE relig     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE hospital  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE locs      -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) General hospital (including VA)'
                  2='(2) Psychiatric hospital'
                  3='(3) Other specialty hospital' ;
  VALUE hotyn     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc1fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc2fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc4fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc5fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc6fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc8fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc27ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc70ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc71ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc88ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc86ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc87ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc85ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc10ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc11ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc73ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc74ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc14ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc15ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc16ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc36ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc37ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc38ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc39ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc49ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc50ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc52ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc24ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc55ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc59ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc48ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc75ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE otp       -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE otptype   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Maintenance program' 2='(2) Detoxification program'
                  3='(3) Both' ;
  VALUE otpall    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE dui_dwi   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE onlydui   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE signlang  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang      -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE langprov  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Staff counselor' 2='(2) On-call interpreter'
                  3='(3) Both' ;
  VALUE lang1fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang2fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang3fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang4fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang5fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang6fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang7fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang8fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang9fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang10ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang11ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang12ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang13ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang14ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang15ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang16ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang17ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE lang18ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc76ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc30ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc31ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc61ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc32ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc62ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc63ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc83ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc34ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc33ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc84ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc64ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE srvc35ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctype4ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctypehif  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctypeh0f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctype7ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctypercf  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctyper0f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctyper1f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctype1ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctype6ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctypeml   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctypeop   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctype2ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ctype3ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE feescale  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE payasst   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE revchk1f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE revchk8f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE revchk5f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE revchk0f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE revchk2f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE revchk3f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE revchk4f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE revchk2a  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE earmark   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE writarra  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE othfac2f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE othfac1f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE othfac3f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE type4fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE t_cli1ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli2ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_clihi   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE h_age1ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE himetnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE hibupnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE hospbed   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE type7fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE t_cli3ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli9ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli10f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_clirc   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE r_age1ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE rcmetnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE rcbupnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE resbed    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE type1fff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE t_cli7ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_climl   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli8ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli6ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cli5ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_cliop   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE o_age1ff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE opmetnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE opbupnum  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE b_pct     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE a_pct     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE d_pct     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE totadmis  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE faccli    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Only this facility'
                  2='(2) This facility plus others' ;
  VALUE facnum    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE acthi     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Actual' 2='(2) Estimate' ;
  VALUE actres    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Actual' 2='(2) Estimate' ;
  VALUE actop     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Actual' 2='(2) Estimate' ;
  VALUE totadest  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Actual' 2='(2) Estimate' ;
  VALUE loc5ffff  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licensed  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licenmh   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licenph   -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE licenhos  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE jcaho     -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE carf      -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE ncqa      -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE coa       -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE othstate  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE internet  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE hasweb    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  0='(0) No' 1='(1) Yes' ;
  VALUE rptlvl    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know'
                  1='(1) Reporting for self'
                  2='(2) Reporting for self and others'
                  3='(3) Client counts reported by another facility' ;
  VALUE t_cli11f  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_clijuv  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_meth    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_bupr    -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE t_climet  -10='(-10) Elsewhere' -9='(-9) Not in survey'
                  -8='(-8) Not in mode' -7='(-7) Not Applicable'
                  -6='(-6) Logical Skip' -5='(-5) Multiple Responses'
                  -4='(-4) Refused' -2='(-2) Missing' -1='(-1) Don''t Know' ;
  VALUE ctyp4_er  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE ctyp7_er  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
  VALUE ctyp1_er  0='(0) Data Not Imputed' 1='(1) Data Imputed' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=521;
INPUT
        CASEID 1-5              MODE 6                  STFIPS 7-8
        REGION 9                DIVISION 10             OTHNONTX 11-13
        DETOX 14-16             TREATMT 17-19           ADMIN 20-22
        FOCUS 23-25             OWNERSHP 26-28          FEDOWN 29-31
        LOC15 32-34             RELIG 35-37             HOSPITAL 38-40
        LOCS 41-43              HOTYN 44-46             SRVC1 47-49
        SRVC2 50-52             SRVC4 53-55             SRVC5 56-58
        SRVC6 59-61             SRVC8 62-64             SRVC27 65-67
        SRVC70 68-70            SRVC71 71-73            SRVC88 74-76
        SRVC86 77-79            SRVC87 80-82            SRVC85 83-85
        SRVC10 86-88            SRVC11 89-91            SRVC73 92-94
        SRVC74 95-97            SRVC14 98-100           SRVC15 101-103
        SRVC16 104-106          SRVC36 107-109          SRVC37 110-112
        SRVC38 113-115          SRVC39 116-118          SRVC49 119-121
        SRVC50 122-124          SRVC52 125-127          SRVC24 128-130
        SRVC55 131-133          SRVC59 134-136          SRVC48 137-139
        SRVC75 140-142          OTP 143-145             OTPTYPE 146-148
        OTPALL 149-151          DUI_DWI 152-154         ONLYDUI 155-157
        SIGNLANG 158-160        LANG 161-163            LANGPROV 164-166
        LANG1 167-169           LANG2 170-172           LANG3 173-175
        LANG4 176-178           LANG5 179-181           LANG6 182-184
        LANG7 185-187           LANG8 188-190           LANG9 191-193
        LANG10 194-196          LANG11 197-199          LANG12 200-202
        LANG13 203-205          LANG14 206-208          LANG15 209-211
        LANG16 212-214          LANG17 215-217          LANG18 218-220
        SRVC76 221-223          SRVC30 224-226          SRVC31 227-229
        SRVC61 230-232          SRVC32 233-235          SRVC62 236-238
        SRVC63 239-241          SRVC83 242-244          SRVC34 245-247
        SRVC33 248-250          SRVC84 251-253          SRVC64 254-256
        SRVC35 257-259          CTYPE4 260-262          CTYPEHI1 263-265
        CTYPEHI2 266-268        CTYPE7 269-271          CTYPERC1 272-274
        CTYPERC3 275-277        CTYPERC4 278-280        CTYPE1 281-283
        CTYPE6 284-286          CTYPEML 287-289         CTYPEOP 290-292
        CTYPE2 293-295          CTYPE3 296-298          FEESCALE 299-301
        PAYASST 302-304         REVCHK1 305-307         REVCHK8 308-310
        REVCHK5 311-313         REVCHK10 314-316        REVCHK15 317-319
        REVCHK2 320-322         REVCHK3 323-325         REVCHK2A 326-328
        EARMARK 329-331         WRITARRA 332-334        OTHFAC2 335-337
        OTHFAC1 338-340         OTHFAC3 341-343         TYPE4 344-346
        T_CLI1 347-349          T_CLI2 350-352          T_CLIHI 353-355
        H_AGE1 356-358          HIMETNUM 359-361        HIBUPNUM 362-364
        HOSPBED 365-367         TYPE7 368-370           T_CLI3 371-373
        T_CLI9 374-376          T_CLI10 377-379         T_CLIRC 380-382
        R_AGE1 383-385          RCMETNUM 386-388        RCBUPNUM 389-391
        RESBED 392-394          TYPE1 395-397           T_CLI7 398-400
        T_CLIML 401-404         T_CLI8 405-407          T_CLI6 408-410
        T_CLI5 411-414          T_CLIOP 415-418         O_AGE1 419-421
        OPMETNUM 422-425        OPBUPNUM 426-428        B_PCT 429-431
        A_PCT 432-434           D_PCT 435-437           TOTADMIS 438-442
        FACCLI 443-445          FACNUM 446-448          ACTHI 449-451
        ACTRES 452-454          ACTOP 455-457           TOTADEST 458-460
        LOC5 461-463            LICENSED 464-466        LICENMH 467-469
        LICENPH 470-472         LICENHOS 473-475        JCAHO 476-478
        CARF 479-481            NCQA 482-484            COA 485-487
        OTHSTATE 488-490        INTERNET 491-493        HASWEB 494-496
        RPTLVL 497-499          T_CLI11 500-503         T_CLIJUV 504-507
        T_METH 508-511          T_BUPR 512-514          T_CLIMET 515-518
        CTYP4_ER 519            CTYP7_ER 520            CTYP1_ER 521
        ;


* SAS LABEL STATEMENT;

LABEL 
   CASEID  = 'Case Identification Number' 
   MODE    = 'Control: Completes 1=phone 2=mail 9=web' 
   STFIPS  = 'Census State FIPS codes label' 
   REGION  = 'Added: Census Region' 
   DIVISION= 'Added: Census Division' 
   OTHNONTX= 'Offer Intake /Assessment/Refer' 
   DETOX   = 'Offer Detox' 
   TREATMT = 'Offer SA Tx' 
   ADMIN   = 'Offer Other SA Services' 
   FOCUS   = 'Is Primary focus SA Tx/MH/Mix/GH/Other' 
   OWNERSHP= 'Ownership' 
   FEDOWN  = 'Federal Government Agency' 
   LOC15   = 'Solo practice' 
   RELIG   = 'Affiliated w/ religious organization' 
   HOSPITAL= 'Located in/operated by hospital' 
   LOCS    = 'Hospital Type' 
   HOTYN   = 'Hotline - yes/no' 
   SRVC1   = 'Assessment comprehensive SA' 
   SRVC2   = 'Assessment  mental health' 
   SRVC4   = 'Therapy family counseling' 
   SRVC5   = 'Therapy group' 
   SRVC6   = 'Therapy individual' 
   SRVC8   = 'Therapy relapse prevention' 
   SRVC27  = 'Therapy aftercare counseling' 
   SRVC70  = 'Pharmacotherapies Antabase' 
   SRVC71  = 'Pharmacotherapies Naltrexone' 
   SRVC88  = 'Pharmacotherapies Campral' 
   SRVC86  = 'Pharmacotherapies Buprenorphine - Subutex' 
   SRVC87  = 'Pharmacotherapies Buprenorphine - Suboxone' 
   SRVC85  = 'Pharmacotherapies Methadone' 
   SRVC10  = 'Testing blood/alcohol' 
   SRVC11  = 'Testing drug/alcohol urine screen' 
   SRVC73  = 'Testing Hepatitis B' 
   SRVC74  = 'Testing Hepatitis C' 
   SRVC14  = 'Testing HIV' 
   SRVC15  = 'Testing STD' 
   SRVC16  = 'Testing TB screen' 
   SRVC36  = 'Transitional Assist. Social Services' 
   SRVC37  = 'Transitional Discharge Plan' 
   SRVC38  = 'Transitional Employment' 
   SRVC39  = 'Transitional Housing Assist' 
   SRVC49  = 'Other Services Case Management' 
   SRVC50  = 'Other Child Care' 
   SRVC52  = 'Other Domestic Violence' 
   SRVC24  = 'Other HIV/AIDS Edu' 
   SRVC55  = 'Other Outcome Follow-Up' 
   SRVC59  = 'Other Transportation Assistance' 
   SRVC48  = 'Other Acupuncture' 
   SRVC75  = 'Other Residential Beds for Client''s children' 
   OTP     = 'Does facility operate an Opioid Treatment Program?' 
   OTPTYPE = 'Is OTP a Maintenance/Detoxification program or Both?' 
   OTPALL  = 'All Clients in OTP?' 
   DUI_DWI = 'Program for DUI/DWI/other offenders' 
   ONLYDUI = 'Are all clients in DUI/DWI program?' 
   SIGNLANG= 'Does Facility offer sign language?' 
   LANG    = 'Tx in language other than English-y/n' 
   LANGPROV= 'Who Tx in language other than English' 
   LANG1   = 'Hopi' 
   LANG2   = 'Lakota' 
   LANG3   = 'Navajo' 
   LANG4   = 'Yupik' 
   LANG5   = 'Tx in Other American Indian/Alaska Native' 
   LANG6   = 'Arabic' 
   LANG7   = 'Chinese' 
   LANG8   = 'Creole' 
   LANG9   = 'French' 
   LANG10  = 'German' 
   LANG11  = 'Hmong' 
   LANG12  = 'Korean' 
   LANG13  = 'Polish' 
   LANG14  = 'Portuguese' 
   LANG15  = 'Russian' 
   LANG16  = 'Spanish' 
   LANG17  = 'Vietnamese' 
   LANG18  = 'Other Language' 
   SRVC76  = 'Accepts adolescents' 
   SRVC30  = 'Program/gr''p for adolescents' 
   SRVC31  = 'Program/gr''p for co-occurring' 
   SRVC61  = 'Program/gr''p for crimn''l justice clients' 
   SRVC32  = 'Program/gr''p for persons with HIV/AIDS' 
   SRVC62  = 'Program/gr''p for gays/lesbians' 
   SRVC63  = 'Program/gr''p for seniors' 
   SRVC83  = 'Accepts women' 
   SRVC34  = 'Program/gr''p for women' 
   SRVC33  = 'Program/gr''p for preg''t/postpart''m women' 
   SRVC84  = 'Accepts men' 
   SRVC64  = 'Program/gr''p for men' 
   SRVC35  = 'Program/gr''p for other groups' 
   CTYPE4  = 'Hosp Inpat''nt SA care offered currently' 
   CTYPEHI1= 'Hosp Inpat''nt Detoxification care offered' 
   CTYPEHI2= 'Hosp Inpat''nt Rehabilitation care offered' 
   CTYPE7  = 'Non-hosp Res SA care offered currently' 
   CTYPERC1= 'Non-hosp Res Detoxification care offered' 
   CTYPERC3= 'Non-hosp Res Short Term Tx' 
   CTYPERC4= 'Non-hosp Res Long Term Tx' 
   CTYPE1  = 'Any Outpat''nt SA care offered currently' 
   CTYPE6  = 'Outpatient Detox offered currently' 
   CTYPEML = 'Outpatient Mathadone maintenance offered' 
   CTYPEOP = 'Day Tx/Partial Hosp offered currently' 
   CTYPE2  = 'Intensive Outpat''nt offered currently' 
   CTYPE3  = 'Regular Outpat''nt offered currently' 
   FEESCALE= 'Uses sliding fee scale' 
   PAYASST = 'Offers no charge or free tx' 
   REVCHK1 = 'Accepts cash or self-payment' 
   REVCHK8 = 'Accepts Medicare payments' 
   REVCHK5 = 'Accepts Medicaid payments' 
   REVCHK10= 'Accepts state financed health ins' 
   REVCHK15= 'Accepts Federal military insurance' 
   REVCHK2 = 'Accepts Private Health insurance' 
   REVCHK3 = 'Accepts Free Tx to all Clients' 
   REVCHK2A= 'Accepts Other Payments' 
   EARMARK = 'Receive any Fed,State,C''nty,Local Funds' 
   WRITARRA= 'Agrmnts/contrs w/Mang''d Care Org' 
   OTHFAC2 = 'Client counts-This Facility Only' 
   OTHFAC1 = 'Client counts-Fac Combined w/Others' 
   OTHFAC3 = 'Cannot Provide Any Client Counts' 
   TYPE4   = 'Any patients rec''d Hosp Inpat''nt SA services, 3/31/05' 
   T_CLI1  = 'Hosp. Inpatient clients, detox' 
   T_CLI2  = 'Hosp. Inpatient clients, Tx' 
   T_CLIHI = 'Total Number of Hospital Inpatients' 
   H_AGE1  = 'Hosp Inp Clients Under 18 years old' 
   HIMETNUM= 'Total Methadone Inpatients' 
   HIBUPNUM= 'Total Buprenorphine Inpatients' 
   HOSPBED = 'Total Beds Designated-Hospital Inpatient' 
   TYPE7   = 'Any clients rec''d Res Non-Hosp SA services, 3/31/05' 
   T_CLI3  = 'Residential Clients, Detox' 
   T_CLI9  = 'Residential Clients, Short-term Tx' 
   T_CLI10 = 'Residential Clients, Long-term Tx' 
   T_CLIRC = 'Total Residential Clients' 
   R_AGE1  = 'Residential Clients Under 18 years old' 
   RCMETNUM= 'Total Methadone Residential' 
   RCBUPNUM= 'Total Buprenorphine Residential' 
   RESBED  = 'Total Beds-Residential Clients' 
   TYPE1   = 'Any clients rec''d Outpat''nt SA services, 3/31/05' 
   T_CLI7  = 'Clients in Outpat''nt detox' 
   T_CLIML = 'Clients in Outpat''nt meth Treat.' 
   T_CLI8  = 'Clients in Day Tx/Partial Hosp' 
   T_CLI6  = 'Clients in Intensive Outpat''nt' 
   T_CLI5  = 'Clients in regular Outpat''nt Care' 
   T_CLIOP = 'Total Number of Outpat''nt Clients' 
   O_AGE1  = 'Outpat''nt clients under 18 years old' 
   OPMETNUM= 'Total Methadone Outpat''nts' 
   OPBUPNUM= 'Total Buprenorphine Outpat''nts' 
   B_PCT   = '% of Clients Treated for Alc/Drug Abuse' 
   A_PCT   = '% of Clients Treated for Alc Abuse' 
   D_PCT   = '% of Clients Treated for Drug Abuse' 
   TOTADMIS= 'Total # of admissions for Sub Abuse Tx' 
   FACCLI  = 'Other facilities included in client ct' 
   FACNUM  = '# of Facilities in Client Count Data' 
   ACTHI   = 'Actual or estimate hosp inpat''nt client ct' 
   ACTRES  = 'Actual or estimate non-hosp res client ct' 
   ACTOP   = 'Actual or estimate outpat''nt client ct' 
   TOTADEST= 'Actual or Estimate admis no.' 
   LOC5    = 'Setting, Halfway House' 
   LICENSED= 'Licns''d/certif''d by State SA Agency' 
   LICENMH = 'Licns''d/certif''d by Mental Health Dept.' 
   LICENPH = 'Licns''d/certif''d by Public Health Dept.' 
   LICENHOS= 'Licns''d/certif''d by Hospital authority' 
   JCAHO   = 'Accredt''d by JCAHO' 
   CARF    = 'Accredt''d by CARF' 
   NCQA    = 'Accredt''d by NCQA' 
   COA     = 'Accredt''d by COA' 
   OTHSTATE= 'Licns''d/certif''d by other State Agency' 
   INTERNET= 'Has internet access' 
   HASWEB  = 'Has Web site- y/n' 
   RPTLVL  = 'Added: Reporting for Self, Self & Others, No Counts' 
   T_CLI11 = 'Added: Total t_cli11 3/29/05' 
   T_CLIJUV= 'Added: Total t_cli11 Under Age 18 3/29/05' 
   T_METH  = 'Added: Total HI, RC, & OP meth clients' 
   T_BUPR  = 'Added: Total HI, RC, & OP bupr clients' 
   T_CLIMET= 'Added: Total Meth/Bupren Detox/Maint 3/29/05' 
   CTYP4_ER= 'Flag: Hosp Inpat''nt SA care offered currently' 
   CTYP7_ER= 'Flag: Non-hosp Res SA care offered currently' 
   CTYP1_ER= 'Flag: Any Outpat''nt SA care offered currently' 
        ; 


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (OTHNONTX <= -1) THEN OTHNONTX = .;
   IF (DETOX <= -1) THEN DETOX = .;
   IF (TREATMT <= -1) THEN TREATMT = .;
   IF (ADMIN <= -1) THEN ADMIN = .;
   IF (FOCUS <= -1) THEN FOCUS = .;
   IF (OWNERSHP <= -1) THEN OWNERSHP = .;
   IF (FEDOWN <= -1) THEN FEDOWN = .;
   IF (LOC15 <= -1) THEN LOC15 = .;
   IF (RELIG <= -1) THEN RELIG = .;
   IF (HOSPITAL <= -1) THEN HOSPITAL = .;
   IF (LOCS <= -1) THEN LOCS = .;
   IF (HOTYN <= -1) THEN HOTYN = .;
   IF (SRVC1 <= -1) THEN SRVC1 = .;
   IF (SRVC2 <= -1) THEN SRVC2 = .;
   IF (SRVC4 <= -1) THEN SRVC4 = .;
   IF (SRVC5 <= -1) THEN SRVC5 = .;
   IF (SRVC6 <= -1) THEN SRVC6 = .;
   IF (SRVC8 <= -1) THEN SRVC8 = .;
   IF (SRVC27 <= -1) THEN SRVC27 = .;
   IF (SRVC70 <= -1) THEN SRVC70 = .;
   IF (SRVC71 <= -1) THEN SRVC71 = .;
   IF (SRVC88 <= -1) THEN SRVC88 = .;
   IF (SRVC86 <= -1) THEN SRVC86 = .;
   IF (SRVC87 <= -1) THEN SRVC87 = .;
   IF (SRVC85 <= -1) THEN SRVC85 = .;
   IF (SRVC10 <= -1) THEN SRVC10 = .;
   IF (SRVC11 <= -1) THEN SRVC11 = .;
   IF (SRVC73 <= -1) THEN SRVC73 = .;
   IF (SRVC74 <= -1) THEN SRVC74 = .;
   IF (SRVC14 <= -1) THEN SRVC14 = .;
   IF (SRVC15 <= -1) THEN SRVC15 = .;
   IF (SRVC16 <= -1) THEN SRVC16 = .;
   IF (SRVC36 <= -1) THEN SRVC36 = .;
   IF (SRVC37 <= -1) THEN SRVC37 = .;
   IF (SRVC38 <= -1) THEN SRVC38 = .;
   IF (SRVC39 <= -1) THEN SRVC39 = .;
   IF (SRVC49 <= -1) THEN SRVC49 = .;
   IF (SRVC50 <= -1) THEN SRVC50 = .;
   IF (SRVC52 <= -1) THEN SRVC52 = .;
   IF (SRVC24 <= -1) THEN SRVC24 = .;
   IF (SRVC55 <= -1) THEN SRVC55 = .;
   IF (SRVC59 <= -1) THEN SRVC59 = .;
   IF (SRVC48 <= -1) THEN SRVC48 = .;
   IF (SRVC75 <= -1) THEN SRVC75 = .;
   IF (OTP <= -1) THEN OTP = .;
   IF (OTPTYPE <= -1) THEN OTPTYPE = .;
   IF (OTPALL <= -1) THEN OTPALL = .;
   IF (DUI_DWI <= -1) THEN DUI_DWI = .;
   IF (ONLYDUI <= -1) THEN ONLYDUI = .;
   IF (SIGNLANG <= -1) THEN SIGNLANG = .;
   IF (LANG <= -1) THEN LANG = .;
   IF (LANGPROV <= -1) THEN LANGPROV = .;
   IF (LANG1 <= -1) THEN LANG1 = .;
   IF (LANG2 <= -1) THEN LANG2 = .;
   IF (LANG3 <= -1) THEN LANG3 = .;
   IF (LANG4 <= -1) THEN LANG4 = .;
   IF (LANG5 <= -1) THEN LANG5 = .;
   IF (LANG6 <= -1) THEN LANG6 = .;
   IF (LANG7 <= -1) THEN LANG7 = .;
   IF (LANG8 <= -1) THEN LANG8 = .;
   IF (LANG9 <= -1) THEN LANG9 = .;
   IF (LANG10 <= -1) THEN LANG10 = .;
   IF (LANG11 <= -1) THEN LANG11 = .;
   IF (LANG12 <= -1) THEN LANG12 = .;
   IF (LANG13 <= -1) THEN LANG13 = .;
   IF (LANG14 <= -1) THEN LANG14 = .;
   IF (LANG15 <= -1) THEN LANG15 = .;
   IF (LANG16 <= -1) THEN LANG16 = .;
   IF (LANG17 <= -1) THEN LANG17 = .;
   IF (LANG18 <= -1) THEN LANG18 = .;
   IF (SRVC76 <= -1) THEN SRVC76 = .;
   IF (SRVC30 <= -1) THEN SRVC30 = .;
   IF (SRVC31 <= -1) THEN SRVC31 = .;
   IF (SRVC61 <= -1) THEN SRVC61 = .;
   IF (SRVC32 <= -1) THEN SRVC32 = .;
   IF (SRVC62 <= -1) THEN SRVC62 = .;
   IF (SRVC63 <= -1) THEN SRVC63 = .;
   IF (SRVC83 <= -1) THEN SRVC83 = .;
   IF (SRVC34 <= -1) THEN SRVC34 = .;
   IF (SRVC33 <= -1) THEN SRVC33 = .;
   IF (SRVC84 <= -1) THEN SRVC84 = .;
   IF (SRVC64 <= -1) THEN SRVC64 = .;
   IF (SRVC35 <= -1) THEN SRVC35 = .;
   IF (CTYPE4 <= -1) THEN CTYPE4 = .;
   IF (CTYPEHI1 <= -1) THEN CTYPEHI1 = .;
   IF (CTYPEHI2 <= -1) THEN CTYPEHI2 = .;
   IF (CTYPE7 <= -1) THEN CTYPE7 = .;
   IF (CTYPERC1 <= -1) THEN CTYPERC1 = .;
   IF (CTYPERC3 <= -1) THEN CTYPERC3 = .;
   IF (CTYPERC4 <= -1) THEN CTYPERC4 = .;
   IF (CTYPE1 <= -1) THEN CTYPE1 = .;
   IF (CTYPE6 <= -1) THEN CTYPE6 = .;
   IF (CTYPEML <= -1) THEN CTYPEML = .;
   IF (CTYPEOP <= -1) THEN CTYPEOP = .;
   IF (CTYPE2 <= -1) THEN CTYPE2 = .;
   IF (CTYPE3 <= -1) THEN CTYPE3 = .;
   IF (FEESCALE <= -1) THEN FEESCALE = .;
   IF (PAYASST <= -1) THEN PAYASST = .;
   IF (REVCHK1 <= -1) THEN REVCHK1 = .;
   IF (REVCHK8 <= -1) THEN REVCHK8 = .;
   IF (REVCHK5 <= -1) THEN REVCHK5 = .;
   IF (REVCHK10 <= -1) THEN REVCHK10 = .;
   IF (REVCHK15 <= -1) THEN REVCHK15 = .;
   IF (REVCHK2 <= -1) THEN REVCHK2 = .;
   IF (REVCHK3 <= -1) THEN REVCHK3 = .;
   IF (REVCHK2A <= -1) THEN REVCHK2A = .;
   IF (EARMARK <= -1) THEN EARMARK = .;
   IF (WRITARRA <= -1) THEN WRITARRA = .;
   IF (OTHFAC2 <= -1) THEN OTHFAC2 = .;
   IF (OTHFAC1 <= -1) THEN OTHFAC1 = .;
   IF (OTHFAC3 <= -1) THEN OTHFAC3 = .;
   IF (TYPE4 <= -1) THEN TYPE4 = .;
   IF (T_CLI1 <= -1) THEN T_CLI1 = .;
   IF (T_CLI2 <= -1) THEN T_CLI2 = .;
   IF (T_CLIHI <= -1) THEN T_CLIHI = .;
   IF (H_AGE1 <= -1) THEN H_AGE1 = .;
   IF (HIMETNUM <= -1) THEN HIMETNUM = .;
   IF (HIBUPNUM <= -1) THEN HIBUPNUM = .;
   IF (HOSPBED <= -1) THEN HOSPBED = .;
   IF (TYPE7 <= -1) THEN TYPE7 = .;
   IF (T_CLI3 <= -1) THEN T_CLI3 = .;
   IF (T_CLI9 <= -1) THEN T_CLI9 = .;
   IF (T_CLI10 <= -1) THEN T_CLI10 = .;
   IF (T_CLIRC <= -1) THEN T_CLIRC = .;
   IF (R_AGE1 <= -1) THEN R_AGE1 = .;
   IF (RCMETNUM <= -1) THEN RCMETNUM = .;
   IF (RCBUPNUM <= -1) THEN RCBUPNUM = .;
   IF (RESBED <= -1) THEN RESBED = .;
   IF (TYPE1 <= -1) THEN TYPE1 = .;
   IF (T_CLI7 <= -1) THEN T_CLI7 = .;
   IF (T_CLIML <= -1) THEN T_CLIML = .;
   IF (T_CLI8 <= -1) THEN T_CLI8 = .;
   IF (T_CLI6 <= -1) THEN T_CLI6 = .;
   IF (T_CLI5 <= -1) THEN T_CLI5 = .;
   IF (T_CLIOP <= -1) THEN T_CLIOP = .;
   IF (O_AGE1 <= -1) THEN O_AGE1 = .;
   IF (OPMETNUM <= -1) THEN OPMETNUM = .;
   IF (OPBUPNUM <= -1) THEN OPBUPNUM = .;
   IF (B_PCT <= -1) THEN B_PCT = .;
   IF (A_PCT <= -1) THEN A_PCT = .;
   IF (D_PCT <= -1) THEN D_PCT = .;
   IF (TOTADMIS <= -1) THEN TOTADMIS = .;
   IF (FACCLI <= -1) THEN FACCLI = .;
   IF (FACNUM <= -1) THEN FACNUM = .;
   IF (ACTHI <= -1) THEN ACTHI = .;
   IF (ACTRES <= -1) THEN ACTRES = .;
   IF (ACTOP <= -1) THEN ACTOP = .;
   IF (TOTADEST <= -1) THEN TOTADEST = .;
   IF (LOC5 <= -1) THEN LOC5 = .;
   IF (LICENSED <= -1) THEN LICENSED = .;
   IF (LICENMH <= -1) THEN LICENMH = .;
   IF (LICENPH <= -1) THEN LICENPH = .;
   IF (LICENHOS <= -1) THEN LICENHOS = .;
   IF (JCAHO <= -1) THEN JCAHO = .;
   IF (CARF <= -1) THEN CARF = .;
   IF (NCQA <= -1) THEN NCQA = .;
   IF (COA <= -1) THEN COA = .;
   IF (OTHSTATE <= -1) THEN OTHSTATE = .;
   IF (INTERNET <= -1) THEN INTERNET = .;
   IF (HASWEB <= -1) THEN HASWEB = .;
   IF (RPTLVL <= -1) THEN RPTLVL = .;
   IF (T_CLI11 <= -1) THEN T_CLI11 = .;
   IF (T_CLIJUV <= -1) THEN T_CLIJUV = .;
   IF (T_METH <= -1) THEN T_METH = .;
   IF (T_BUPR <= -1) THEN T_BUPR = .;
   IF (T_CLIMET <= -1) THEN T_CLIMET = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT MODE mode. STFIPS stfips. REGION region.
         DIVISION division. OTHNONTX othnontx. DETOX detox.
         TREATMT treatmt. ADMIN admin. FOCUS focus.
         OWNERSHP ownershp. FEDOWN fedown. LOC15 loc15fff.
         RELIG relig. HOSPITAL hospital. LOCS locs.
         HOTYN hotyn. SRVC1 srvc1fff. SRVC2 srvc2fff.
         SRVC4 srvc4fff. SRVC5 srvc5fff. SRVC6 srvc6fff.
         SRVC8 srvc8fff. SRVC27 srvc27ff. SRVC70 srvc70ff.
         SRVC71 srvc71ff. SRVC88 srvc88ff. SRVC86 srvc86ff.
         SRVC87 srvc87ff. SRVC85 srvc85ff. SRVC10 srvc10ff.
         SRVC11 srvc11ff. SRVC73 srvc73ff. SRVC74 srvc74ff.
         SRVC14 srvc14ff. SRVC15 srvc15ff. SRVC16 srvc16ff.
         SRVC36 srvc36ff. SRVC37 srvc37ff. SRVC38 srvc38ff.
         SRVC39 srvc39ff. SRVC49 srvc49ff. SRVC50 srvc50ff.
         SRVC52 srvc52ff. SRVC24 srvc24ff. SRVC55 srvc55ff.
         SRVC59 srvc59ff. SRVC48 srvc48ff. SRVC75 srvc75ff.
         OTP otp. OTPTYPE otptype. OTPALL otpall.
         DUI_DWI dui_dwi. ONLYDUI onlydui. SIGNLANG signlang.
         LANG lang. LANGPROV langprov. LANG1 lang1fff.
         LANG2 lang2fff. LANG3 lang3fff. LANG4 lang4fff.
         LANG5 lang5fff. LANG6 lang6fff. LANG7 lang7fff.
         LANG8 lang8fff. LANG9 lang9fff. LANG10 lang10ff.
         LANG11 lang11ff. LANG12 lang12ff. LANG13 lang13ff.
         LANG14 lang14ff. LANG15 lang15ff. LANG16 lang16ff.
         LANG17 lang17ff. LANG18 lang18ff. SRVC76 srvc76ff.
         SRVC30 srvc30ff. SRVC31 srvc31ff. SRVC61 srvc61ff.
         SRVC32 srvc32ff. SRVC62 srvc62ff. SRVC63 srvc63ff.
         SRVC83 srvc83ff. SRVC34 srvc34ff. SRVC33 srvc33ff.
         SRVC84 srvc84ff. SRVC64 srvc64ff. SRVC35 srvc35ff.
         CTYPE4 ctype4ff. CTYPEHI1 ctypehif. CTYPEHI2 ctypeh0f.
         CTYPE7 ctype7ff. CTYPERC1 ctypercf. CTYPERC3 ctyper0f.
         CTYPERC4 ctyper1f. CTYPE1 ctype1ff. CTYPE6 ctype6ff.
         CTYPEML ctypeml. CTYPEOP ctypeop. CTYPE2 ctype2ff.
         CTYPE3 ctype3ff. FEESCALE feescale. PAYASST payasst.
         REVCHK1 revchk1f. REVCHK8 revchk8f. REVCHK5 revchk5f.
         REVCHK10 revchk0f. REVCHK15 revchk2f. REVCHK2 revchk3f.
         REVCHK3 revchk4f. REVCHK2A revchk2a. EARMARK earmark.
         WRITARRA writarra. OTHFAC2 othfac2f. OTHFAC1 othfac1f.
         OTHFAC3 othfac3f. TYPE4 type4fff. T_CLI1 t_cli1ff.
         T_CLI2 t_cli2ff. T_CLIHI t_clihi. H_AGE1 h_age1ff.
         HIMETNUM himetnum. HIBUPNUM hibupnum. HOSPBED hospbed.
         TYPE7 type7fff. T_CLI3 t_cli3ff. T_CLI9 t_cli9ff.
         T_CLI10 t_cli10f. T_CLIRC t_clirc. R_AGE1 r_age1ff.
         RCMETNUM rcmetnum. RCBUPNUM rcbupnum. RESBED resbed.
         TYPE1 type1fff. T_CLI7 t_cli7ff. T_CLIML t_climl.
         T_CLI8 t_cli8ff. T_CLI6 t_cli6ff. T_CLI5 t_cli5ff.
         T_CLIOP t_cliop. O_AGE1 o_age1ff. OPMETNUM opmetnum.
         OPBUPNUM opbupnum. B_PCT b_pct. A_PCT a_pct.
         D_PCT d_pct. TOTADMIS totadmis. FACCLI faccli.
         FACNUM facnum. ACTHI acthi. ACTRES actres.
         ACTOP actop. TOTADEST totadest. LOC5 loc5ffff.
         LICENSED licensed. LICENMH licenmh. LICENPH licenph.
         LICENHOS licenhos. JCAHO jcaho. CARF carf.
         NCQA ncqa. COA coa. OTHSTATE othstate.
         INTERNET internet. HASWEB hasweb. RPTLVL rptlvl.
         T_CLI11 t_cli11f. T_CLIJUV t_clijuv. T_METH t_meth.
         T_BUPR t_bupr. T_CLIMET t_climet. CTYP4_ER ctyp4_er.
         CTYP7_ER ctyp7_er. CTYP1_ER ctyp1_er.  ;
*/

RUN ;
